@@ -23,15 +23,19 @@
 #ifndef Esound_H
 #define Esound_H
 
+#import <Foundation/NSObject.h>
+
+@class NSFileHandle;
+
+@protocol CynthiuneBundle;
+@protocol Output;
+
 @interface Esound : NSObject <CynthiuneBundle, Output>
 {
   id parentPlayer;
 
   int rate;
   int channels;
-  int bytes;
-
-  NSData *currentChunk;
 
   NSFileHandle *esd;
 }
