@@ -1,8 +1,10 @@
 /* OSS.h - this file is part of Cynthiune
  *
  * Copyright (C) 2002-2004 Wolfgang Sourdeau
+ *               2012 The Free Software Foundation
  *
  * Author: Wolfgang Sourdeau <wolfgang@contre.com>
+ *         Riccardo Mottola <rm@gnu.org>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,15 +25,24 @@
 #ifndef OSS_H
 #define OSS_H
 
+#import <Foundation/NSObject.h>
+#import <Cynthiune/CynthiuneBundle.h>
+#import <Cynthiune/Output.h>
+
+@class NSFileHandle;
+
+@protocol CynthiuneBundle;
+@protocol Output;
+
 @interface OSS : NSObject <CynthiuneBundle, Output>
 {
   id parentPlayer;
 
   NSFileHandle *dsp;
-  int bytes;
 
   unsigned int channels;
   unsigned long rate;
+  Endianness endianness;
 }
 
 @end
