@@ -23,6 +23,10 @@
 #ifndef CYNTHIUNEPOPUPBUTTON_H
 #define CYNTHIUNEPOPUPBUTTON_H
 
+#import <AppKit/NSPopUpButton.h>
+
+@class NSString;
+
 @interface CynthiunePopUpButton : NSPopUpButton
 {
 }
